foundation_formtags package
===========================

Subpackages
-----------

.. toctree::

    foundation_formtags.templatetags
    foundation_formtags.tests

Module contents
---------------

.. automodule:: foundation_formtags
    :members:
    :undoc-members:
    :show-inheritance:
